@@ -2,5 +2,7 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
+mod macho;
+pub use macho::*;
 mod sdk;
 pub use sdk::*;
